Module error

Module error 

The single error type of the framework.

Hand-written Display/Error impls: the project’s dependency discipline (master doc 72) does not admit thiserror for one enum.

Enums

Error
Everything that can go wrong in a weida operation.
ErrorCode
Wire codes carried in an ERROR frame (docs/PROTOCOL.md 6.4).
LossCause
Why a connection is gone.
StopReason
Why a peer refused to receive more payload, as carried by STOP_SENDING’s QUIC application error code.

Type Aliases

Result
Convenience alias used throughout the framework.